UI/UserInterface.py

changeset 3990
5dd6edf8540a
parent 3788
195dd519bf29
child 4021
195a471c327b
diff -r 57354896fd29 -r 5dd6edf8540a UI/UserInterface.py
--- a/UI/UserInterface.py	Mon Dec 22 14:01:41 2014 +0100
+++ b/UI/UserInterface.py	Mon Dec 22 18:27:16 2014 +0100
@@ -5454,9 +5454,9 @@
     
     def __writeTasks(self):
         """
-        Private slot to write the tasks data to an XML file (.e4t).
-        """
-        fn = os.path.join(Utilities.getConfigDir(), "eric6tasks.e4t")
+        Private slot to write the tasks data to an XML file (.e6t).
+        """
+        fn = os.path.join(Utilities.getConfigDir(), "eric6tasks.e6t")
         f = QFile(fn)
         ok = f.open(QIODevice.WriteOnly)
         if not ok:
@@ -5474,11 +5474,14 @@
         
     def __readTasks(self):
         """
-        Private slot to read in the tasks file (.e4t).
-        """
-        fn = os.path.join(Utilities.getConfigDir(), "eric6tasks.e4t")
+        Private slot to read in the tasks file (.e6t).
+        """
+        fn = os.path.join(Utilities.getConfigDir(), "eric6tasks.e6t")
         if not os.path.exists(fn):
-            return
+            # try again with the old extension
+            fn = os.path.join(Utilities.getConfigDir(), "eric6tasks.e4t")
+            if not os.path.exists(fn):
+                return
         f = QFile(fn)
         if f.open(QIODevice.ReadOnly):
             from E5XML.TasksReader import TasksReader

eric ide

mercurial